starcluster.commands.base.CmdBase

Package starcluster :: Package commands :: Module base :: Class CmdBase |
[hide private]
[frames] | no frames]

# Class CmdBase

source code

    Base class for StarCluster commands

    Each command consists of a class, which has the following properties:

    - Must have a class member 'names' which is a list of the names for
    the command

    - Can optionally define an addopts(self, parser) method which adds options
    to the given parser. This defines the command's options.

Instance Methods | [hide private]
addopts(self, parser) | source code
cancel_command(self, signum, frame) Exits program with return value of 1 | source code
catch_ctrl_c(self, handler=None) Catch ctrl-c interrupt | source code
warn_experimental(self, msg, num_secs=10) Warn user that an experimental feature is being used Counts down from num_secs before continuing | source code
_positive_int(self, option, opt_str, value, parser) | source code
Inherited from `optcomplete.CmdComplete`: `autocomplete` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| parser = `None` hash(x)
| opts = `None` hash(x)
| gopts = `None` hash(x)
| gparser = `None` hash(x)
| subcmds_map = `None` hash(x)
| _cfg = `None` hash(x)
| _ec2 = `None` hash(x)
| _s3 = `None` hash(x)
| _cm = `None` hash(x)
| _nm = `None` hash(x)

Properties | [hide private]
| comp_words Property that returns COMP_WORDS from Bash/Zsh completion
| goptions_dict Returns global options dictionary
| options_dict Returns dictionary of options for this command
| specified_options_dict Return only those options with a non-None value
| log
| cfg Get global StarClusterConfig object
| ec2 Get EasyEC2 object from config and connect to the region specified by the user in the global options (if any)
| cluster_manager Returns ClusterManager object configured with self.cfg and self.ec2
| cm Returns ClusterManager object configured with self.cfg and self.ec2
| node_manager Returns NodeManager object configured with self.cfg and self.ec2
| nm Returns NodeManager object configured with self.cfg and self.ec2
| s3
Inherited from `object`: `__class__`

Property Details | [hide private]

### comp_words Property that returns COMP_WORDS from Bash/Zsh completion Get Method: unreachable.comp_words(self) - Property that returns COMP_WORDS from Bash/Zsh completion

### goptions_dict Returns global options dictionary Get Method: unreachable.goptions_dict(self) - Returns global options dictionary

### options_dict Returns dictionary of options for this command Get Method: unreachable.options_dict(self) - Returns dictionary of options for this command

### specified_options_dict Return only those options with a non-None value Get Method: unreachable.specified_options_dict(self) - Return only those options with a non-None value

### log Get Method: unreachable.log(self)

### cfg Get global StarClusterConfig object Get Method: unreachable.cfg(self) - Get global StarClusterConfig object

### ec2 Get EasyEC2 object from config and connect to the region specified by the user in the global options (if any) Get Method: unreachable.ec2(self) - Get EasyEC2 object from config and connect to the region specified by the user in the global options (if any)

### cluster_manager Returns ClusterManager object configured with self.cfg and self.ec2 Get Method: unreachable.cluster_manager(self) - Returns ClusterManager object configured with self.cfg and self.ec2

### cm Returns ClusterManager object configured with self.cfg and self.ec2 Get Method: unreachable.cluster_manager(self) - Returns ClusterManager object configured with self.cfg and self.ec2

### node_manager Returns NodeManager object configured with self.cfg and self.ec2 Get Method: unreachable.node_manager(self) - Returns NodeManager object configured with self.cfg and self.ec2

### nm Returns NodeManager object configured with self.cfg and self.ec2 Get Method: unreachable.node_manager(self) - Returns NodeManager object configured with self.cfg and self.ec2

### s3 Get Method: unreachable.s3(self)